'use strict';
'use es6';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _immutable = require('immutable');

var _PriceEstimate = require('../../data/PriceEstimate');

var _PriceEstimate2 = _interopRequireDefault(_PriceEstimate);

var _Range = require('../../data/Range');

var _Range2 = _interopRequireDefault(_Range);

var _Utilities = require('../../Utilities');

var _Utilities2 = _interopRequireDefault(_Utilities);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var PriceEstimatesTranslator = function () {
  function PriceEstimatesTranslator() {
    _classCallCheck(this, PriceEstimatesTranslator);
  }

  _createClass(PriceEstimatesTranslator, null, [{
    key: 'translate',
    value: function translate(response) {
      if (!('prices' in response)) {
        throw new ReferenceError('expected prices field');
      }

      var estimates = response['prices'];
      if (!Array.isArray(estimates)) {
        throw new TypeError('expected prices to be an array');
      }

      return (0, _immutable.List)(estimates.map(function (estimate) {
        return PriceEstimatesTranslator.translateEstimate(estimate);
      }));
    }
  }, {
    key: 'translateEstimate',
    value: function translateEstimate(estimate) {
      if (!('localized_display_name' in estimate)) {
        throw new ReferenceError('expected localized display name field');
      }

      if (!('distance' in estimate)) {
        throw new ReferenceError('expected distance field');
      }

      if (!('high_estimate' in estimate)) {
        throw new ReferenceError('expected high estimate field');
      }

      if (!('low_estimate' in estimate)) {
        throw new ReferenceError('expected low_estimate field');
      }

      if (!('duration' in estimate)) {
        throw new ReferenceError('expected duration field');
      }

      if (!('currency_code' in estimate)) {
        throw new ReferenceError('expected currency code field');
      }

      var displayName = estimate['localized_display_name'];
      if (typeof displayName !== 'string') {
        throw new TypeError('expected localized display name to be a string');
      }

      var distance = estimate['distance'];
      if (!_Utilities2.default.isFloat(distance)) {
        throw new TypeError('expected distance to be an integer');
      }

      var duration = estimate['duration'];
      if (!Number.isInteger(duration)) {
        throw new TypeError('expected duration to be an integer');
      }

      // estimates can be null for non-applicable products like Taxi
      var highEstimate = estimate['high_estimate'];
      if (highEstimate === null) {
        highEstimate = undefined;
      } else if (!Number.isInteger(highEstimate)) {
        throw new TypeError('expected high estimate to be an integer');
      }

      var lowEstimate = estimate['low_estimate'];
      if (lowEstimate === null) {
        lowEstimate = undefined;
      } else if (!Number.isInteger(lowEstimate)) {
        throw new TypeError('expected low estimate to be an integer');
      }

      var currencyCode = estimate['currency_code'];

      // currency code can be null for non-applicable products like Taxi
      if (currencyCode === null) {
        currencyCode = undefined;
      } else if (typeof currencyCode !== 'string') {
        throw new TypeError('expected currency code name to be a string');
      }

      var args = (0, _immutable.Map)({
        productName: displayName,
        distance: distance,
        duration: duration,
        range: new _Range2.default({
          high: highEstimate,
          low: lowEstimate
        }),
        currencyCode: currencyCode
      });

      // wont show up unless > 1
      if ('surgeMultiplier' in estimate) {
        var surge = estimate['surgeMultiplier'];
        if (!_Utilities2.default.isFloat(surge)) {
          throw new TypeError('expected surge to be a float');
        }

        args = args.set('surgeMultiplier', surge);
      }

      return new _PriceEstimate2.default(args);
    }
  }]);

  return PriceEstimatesTranslator;
}();

exports.default = PriceEstimatesTranslator;